==> v1.0.3.tar.gz: ucl/README.md <==
# Универсальная коммунистическая лицензия

`Версия 1.0.3` `2024-01-18 12:21:07 MSK +03`

## Определения

**Трудящийся**: человек, для которого приоритетным способом обеспечения своей жизни является производство труда.

**Капиталист**: человек, который является владельцем материальных и трудовых ресурсов, инструментов производства и присваивает в личное владение хотя бы часть прибавочной стоимости в ходе товарного производства.

**Объект лицензирования**: любой результат труда, в отношение которого устанавливаются правовые отношения настоящей лицензией (далее `ОЛ`); `ОЛ` не может быть ничего, кроме артефакта, который потребовал для своего создания производительного труда.

**Автор ОЛ**: человек (или несколько человек), который является автором `ОЛ` и всех сопутствующих материалов, которые он создал непосредственно.

**Потребитель ОЛ**: `трудящийся` или `капиталист`, который использует настоящий `ОЛ`, с соблюдением требований данной лицензии или с нарушением требований данной лицензии.

**Производный объект лицензирования**: `ОЛ` со всеми сопутствующими материалами, в котором доля модификации не превышает 50%; производный `ОЛ` подпадает под действие этой же лицензии в полном объёме.

```mermaid
flowchart TD
  subgraph Потребитель
    Трудящийся
    Капиталист
  end
  subgraph Права
    subgraph отчуждаемые
      ПК[копирования]
      ПМ[модификации]
      ПИ[использования]
    end
    subgraph неотчуждаемые
      ПА[авторское]
    end
    ПК --> ОП[Отчуждаемые права]
    ПМ --> ОП
    ПИ --> ОП
    ПА --> НП[Неотчуждаемые права]
  end
  ОЛ[Объект лицензирования] --> Права
  ОП --> Трудящийся
  ОП --> Автор
  ОП -.-x Капиталист
  Автор --> Капиталист
  НП --> Автор
```

## Права

**Неотчуждаемое право**: такой вид права, который не может быть потерян ни прикаких условиях.

**Авторское право**: неотчуждаемое право автора (или группы авторов) на своё произведение ни при каких условиях; авторское право означает, что атором `ОЛ` является конкретный человек (или группа людей) и ничего более.

**Отчуждаемое право**: такой вид права, который может быть передан или аннулирован по различным основаниям.

**Свободное решение**: решение двух сторон по обладанию отчуждаемыми правами без какого-либо внешнего давления, которое не принуждает любую из сторон  (с явной потерей своей пользы в явную пользу другой стороны или наоброт) передавать или принимать права любой из сторон.

**Право копирования**:  возможное отчуждаемое право, по  свободному решению сторон; копирование -- создание копии ПО. подлежащее данному лицензированию.

**Право модификации**: возможно отчуждаемое право, по свободному решению сторон; модификация -- доработка, декомпиляция. патчинг и другие виды изменений в отношении ПО, которое подлежит данному лицензированию.

**Право использования**: возможное отчуждаемое право, по свободному решению сторон; использование -- использование `ОЛ` по функциональному назначению _и все действия_, связанные с технологией использования такого `ОЛ`, подлежащему данному лицензированию.

**Право владения**: особое, возможно отчуждаемое право, по непосредственному владени `ОЛ`; владение `ОЛ` -- распоряжение конкретным видом `ЛО` или его частью, которое подлежит данному лицензированию.

## Обязанности сторон

`Автор` в рамках определений в настоящей лицензии _разрешает_ всем `трудящимся` мира использовать права на настоящий `ОЛ`:

- копирования;
- использования;
- модификации.

`Автор` в рамках определений настоящей лицензии _запрещает_ всем `капиталистам` мира право копирования, использования, модификации настоящего `ОЛ`, если это не оговорено особо или передача прав не является свободной.

`Автор` _явно_ запрещает использование `ОЛ`, в случае его применения любым способом против `трудящихся`.

`Автор` не даёт _никаких_ гарантий в отношении настоящего `ОЛ`:

- необходимого функционала;
- необходимой архитектуры;
- необходимых архитектурных свойств;
- необходимого качества и/или кодирования, материалов;
- необходимого количества тестирования;
- необходимых возможностей масштабирования;
- отсутствия возможного ущерба;
- возможной упущенной выгоды;
- иных возможных потерь, которые не упомянуты здесь.

`Автор` может дать дополнительные гарантии по своему усмотрению или договорённости с `потребителем`; подобные договорённости оформляются отдельным приложением и оно имеет приоритет надо отказом от гарантий, перечесиленными (или не упомянутыми) выше.

`Автор` гарантирует, что не включает в свой код деструктивный функционал, но оставляет за собой право ограничивать `потребителей` данного `ОЛ` в праве его использовать в случаях нарушения требований настоящей лицензии.

`Трудящиеся` _обязаны_ не передавать права на настоящий `ОЛ` `капиталистам` и не препятствовать передаче этих же прав `трудящимся`, кроме случаев _явного_ использования `трудящимися` настоящего `ОЛ` в пользу `капиталистов`.

В случае использования настоящего `ОЛ` `пользователи` автоматически принимают настоящие коммунистические требования, и соглашаются со всеми положениями настоящего лицензионного требования.

Настоящая лицензия _должна_ сопровождать `ОЛ`, в случае передачи отчуждаемых прав.

## Защита лицензионных требований

`Автор` может в любой момент изменить состав `ОЛ` в любых целях, кроме откровенно деструктивных, для защиты лицензионных требований.
`Автор` может в любой момент изменить версию настоящих лицензионных требований, из-за внесённых им каких-либо изменений в `ОЛ`, но в рамках совместимости с предыдущими лицензионными требованиями.
`Автор` может в любой момент отозвать отчуждаемые права (кроме особых случаев отчуждаемого права владения), если посчитает, что `потребитель` нарушает настоящие лицензионные требования.

## Заключительные положения

Если, какая-либо сторона настоящих лицензионных требований не оговорена или допускает трактовку -- в таком случае, ситуация трактуется приоритетно в пользу `автора`, во вторую очередь в пользу `трудящихся` и никогда в пользу `капиталистов`. Данное требование не распространяется на особые случаи отдельных договорённостей и отчуждаемого права владения и только на основе свободного решения.

==> v1.0.4.tar.gz: ucl/README.md <==
# Универсальная коммунистическая лицензия

`Версия 1.0.4` `2024-01-18 12:32:41 MSK +03`

## Определения

**Трудящийся**: человек, для которого приоритетным способом обеспечения своей жизни является производство труда.

**Капиталист**: человек, который является владельцем материальных и трудовых ресурсов, инструментов производства и присваивает в личное владение хотя бы часть прибавочной стоимости в ходе товарного производства.

**Объект лицензирования**: любой результат труда, в отношение которого устанавливаются правовые отношения настоящей лицензией (далее `ОЛ`); `ОЛ` не может быть ничего, кроме артефакта, который потребовал для своего создания производительного труда.

**Автор ОЛ**: человек (или несколько человек), который является автором `ОЛ` и всех сопутствующих материалов, которые он создал непосредственно.

**Потребитель ОЛ**: `трудящийся` или `капиталист`, который использует настоящий `ОЛ`, с соблюдением требований данной лицензии или с нарушением требований данной лицензии.

**Производный объект лицензирования**: `ОЛ` со всеми сопутствующими материалами, в котором доля модификации не превышает 50%; производный `ОЛ` подпадает под действие этой же лицензии в полном объёме.

```mermaid
flowchart TD
  subgraph Потребитель
    Трудящийся
    Капиталист
  end
  subgraph Права
    subgraph отчуждаемые
      ПК[копирования]
      ПМ[модификации]
      ПИ[использования]
    end
    subgraph неотчуждаемые
      ПА[авторское]
    end
    ПК --> ОП[Отчуждаемые права]
    ПМ --> ОП
    ПИ --> ОП
    ПА --> НП[Неотчуждаемые права]
  end
  ОЛ[Объект лицензирования] --> Права
  ОП --> Трудящийся
  ОП --> Автор
  ОП -.-x Капиталист
  Автор --> Капиталист
  НП --> Автор
```

## Права

**Неотчуждаемое право**: такой вид права, который не может быть потерян ни прикаких условиях.

**Авторское право**: неотчуждаемое право автора (или группы авторов) на своё произведение ни при каких условиях; авторское право означает, что автором `ОЛ` является конкретный человек (или группа людей) и ничего более.

**Отчуждаемое право**: такой вид права, который может быть передан или отозван по различным основаниям.

**Свободное решение**: решение двух сторон по обладанию отчуждаемыми правами без какого-либо внешнего давления, которое не принуждает любую из сторон  (с явной потерей своей пользы в явную пользу другой стороны или наоброт) передавать или принимать права любой из сторон.

**Право копирования**:  возможное отчуждаемое право, по  свободному решению сторон; копирование -- создание копии ПО. подлежащее данному лицензированию.

**Право модификации**: возможно отчуждаемое право, по свободному решению сторон; модификация -- доработка, декомпиляция. патчинг и другие виды изменений в отношении ПО, которое подлежит данному лицензированию.

**Право использования**: возможное отчуждаемое право, по свободному решению сторон; использование -- использование `ОЛ` по функциональному назначению _и все действия_, связанные с технологией использования такого `ОЛ`, подлежащему данному лицензированию.

**Право владения**: особое, возможно отчуждаемое право, по непосредственному владени `ОЛ`; владение `ОЛ` -- распоряжение конкретным видом `ЛО` или его частью, которое подлежит данному лицензированию.

## Обязанности сторон

`Автор` в рамках определений в настоящей лицензии _разрешает_ всем `трудящимся` мира использовать права на настоящий `ОЛ`:

- копирования;
- использования;
- модификации.

`Автор` в рамках определений настоящей лицензии _запрещает_ всем `капиталистам` мира право копирования, использования, модификации настоящего `ОЛ`, если это не оговорено особо или передача прав не является свободной.

`Автор` _явно_ запрещает использование `ОЛ`, в случае его применения любым способом против `трудящихся`.

`Автор` не даёт _никаких_ гарантий в отношении настоящего `ОЛ`:

- необходимого функционала;
- необходимой архитектуры;
- необходимых архитектурных свойств;
- необходимого качества и/или кодирования, материалов;
- необходимого количества тестирования;
- необходимых возможностей масштабирования;
- отсутствия возможного ущерба;
- возможной упущенной выгоды;
- иных возможных потерь, которые не упомянуты здесь.

`Автор` может дать дополнительные гарантии по своему усмотрению или договорённости с `потребителем`; подобные договорённости оформляются отдельным приложением и оно имеет приоритет надо отказом от гарантий, перечесиленными (или не упомянутыми) выше.

`Автор` гарантирует, что не включает в свой код деструктивный функционал, но оставляет за собой право ограничивать `потребителей` данного `ОЛ` в праве его использовать в случаях нарушения требований настоящей лицензии.

`Трудящиеся` _обязаны_ не передавать права на настоящий `ОЛ` `капиталистам` и не препятствовать передаче этих же прав `трудящимся`, кроме случаев _явного_ использования `трудящимися` настоящего `ОЛ` в пользу `капиталистов`.

В случае использования настоящего `ОЛ` `пользователи` автоматически принимают настоящие коммунистические требования, и соглашаются со всеми положениями настоящего лицензионного требования.

Настоящая лицензия _должна_ сопровождать `ОЛ`, в случае передачи отчуждаемых прав.

## Защита лицензионных требований

`Автор` может в любой момент изменить состав `ОЛ` в любых целях, кроме откровенно деструктивных, для защиты лицензионных требований.
`Автор` может в любой момент изменить версию настоящих лицензионных требований, из-за внесённых им каких-либо изменений в `ОЛ`, но в рамках совместимости с предыдущими лицензионными требованиями.
`Автор` может в любой момент отозвать отчуждаемые права (кроме особых случаев отчуждаемого права владения), если посчитает, что `потребитель` нарушает настоящие лицензионные требования.

## Заключительные положения

Если, какая-либо сторона настоящих лицензионных требований не оговорена или допускает трактовку -- в таком случае, ситуация трактуется приоритетно в пользу `автора`, во вторую очередь в пользу `трудящихся` и никогда в пользу `капиталистов`. Данное требование не распространяется на особые случаи отдельных договорённостей и отчуждаемого права владения и только на основе свободного решения.
